package net.pricefx.logic.core.config;

import org.jasypt.encryption.pbe.PBEStringEncryptor;
import org.jasypt.encryption.pbe.StandardPBEStringEncryptor;
import org.jasypt.exceptions.EncryptionOperationNotPossibleException;

import java.io.IOException;

/**
 * Simple (and somehow silly) string-based encryptor used for hiding password as clear text in config file.
 */
public class Encryptor {

	private static PBEStringEncryptor encryptor = new StandardPBEStringEncryptor();

	static {
		/** Secret used to encrypt/decrypt partition passwords in config file. */
		encryptor.setPassword("xMgpAv6Pe6ZNGnEaW762");
	}

	/**
	 * Encrypt the input message
	 *
	 * @param message the message to be encrypted
	 * @return the result of encryption
	 */
	public static String encrypt(String message) {
		return encryptor.encrypt(message);
	}


	/**
	 * Decrypt an encrypted message
	 *
	 * @param encryptedMessage the encrypted message to be decrypted
	 * @return the result of decryption
	 * @throws IOException input is not encrypted text.
	 */
	public static String decrypt(String encryptedMessage) throws IOException {
		try {
			return encryptor.decrypt(encryptedMessage);
		} catch (EncryptionOperationNotPossibleException e) {
			throw new IOException(String.format("Decryption of supplied input is impossible. Input '%s' is not an encrypted text.", encryptedMessage), e);
		}
	}

}
